@@ -2,6 +2,7 @@ import numpy as np
 import tensorflow as tf
 from tensorflow.keras.layers import Layer
 
+
 class MaskedConv2D(Layer):
     """
     Masked 2-dimensional convolutional layer. For full documentation of the convolutional architecture, see the
@@ -14,14 +15,14 @@ class MaskedConv2D(Layer):
     def __init__(
             self,
             filters,
-            kernel_size = 3,
-            padding = 'same',
-            strides = 1,
-            activation = None,
-            use_bias = True,
-            kernel_initializer = 'random_normal',
-            bias_initializer = 'zeros',
-            mask_initializer = 'ones',
+            kernel_size=3,
+            padding='same',
+            strides=1,
+            activation=None,
+            use_bias=True,
+            kernel_initializer='random_normal',
+            bias_initializer='zeros',
+            mask_initializer='ones',
             **kwargs
     ):
         """
@@ -45,10 +46,11 @@ class MaskedConv2D(Layer):
             The bias initialization function to use
         mask_initializer : str or keras initialization function (default 'ones')
             The mask initialization function to use
-        
+
     """
         super(MaskedConv2D, self).__init__(**kwargs)
-        self.filters = int(filters) if not isinstance(filters, int) else filters
+        self.filters = int(filters) if not isinstance(
+            filters, int) else filters
         self.kernel_size = kernel_size
         self.padding = padding
         self.strides = tuple(strides) if isinstance(strides, list) else strides
@@ -60,7 +62,8 @@ class MaskedConv2D(Layer):
 
     @property
     def kernel_size(self):
-        return self._kernel_size   
+        return self._kernel_size
+
     @kernel_size.setter
     def kernel_size(self, value):
         if isinstance(value, int):
@@ -70,39 +73,40 @@ class MaskedConv2D(Layer):
 
     def build(self, input_shape):
         self.w = self.add_weight(
-            shape = (self.kernel_size[0], self.kernel_size[1], input_shape[-1], self.filters),
-            initializer = self.kernel_initializer,
-            trainable = True,
-            name = 'weights'
+            shape=(self.kernel_size[0], self.kernel_size[1],
+                   input_shape[-1], self.filters),
+            initializer=self.kernel_initializer,
+            trainable=True,
+            name='weights'
         )
         self.w_mask = self.add_weight(
-            shape = self.w.shape,
-            initializer = self.mask_initializer,
-            trainable = False,
-            name = 'weights_mask'
+            shape=self.w.shape,
+            initializer=self.mask_initializer,
+            trainable=False,
+            name='weights_mask'
         )
 
         if self.use_bias:
             self.b = self.add_weight(
-                shape = (self.filters,),
-                initializer = self.bias_initializer,
-                trainable = True,
-                name = 'bias'
+                shape=(self.filters,),
+                initializer=self.bias_initializer,
+                trainable=True,
+                name='bias'
             )
             self.b_mask = self.add_weight(
-                shape = self.b.shape,
-                initializer = self.mask_initializer,
-                trainable = False,
-                name = 'bias_mask'
+                shape=self.b.shape,
+                initializer=self.mask_initializer,
+                trainable=False,
+                name='bias_mask'
             )
 
     def call(self, inputs):
         conv_output = tf.nn.convolution(
             inputs,
             self.w * self.w_mask,
-            padding = self.padding.upper(),
-            strides = self.strides,
-            data_format = 'NHWC'
+            padding=self.padding.upper(),
+            strides=self.strides,
+            data_format='NHWC'
         )
         if self.use_bias:
             conv_output = conv_output + (self.b * self.b_mask)
@@ -112,15 +116,15 @@ class MaskedConv2D(Layer):
         config = super().get_config().copy()
         config.update(
             {
-                'filters' : self.filters,
-                'kernel_size' : list(self.kernel_size),
-                'padding' : self.padding,
-                'strides' : self.strides,
-                'activation' : tf.keras.activations.serialize(self.activation),
-                'use_bias' : self.use_bias,
-                'kernel_initializer' : tf.keras.initializers.serialize(self.kernel_initializer),
-                'bias_initializer' : tf.keras.initializers.serialize(self.bias_initializer),
-                'mask_initializer' : tf.keras.initializers.serialize(self.mask_initializer)
+                'filters': self.filters,
+                'kernel_size': list(self.kernel_size),
+                'padding': self.padding,
+                'strides': self.strides,
+                'activation': tf.keras.activations.serialize(self.activation),
+                'use_bias': self.use_bias,
+                'kernel_initializer': tf.keras.initializers.serialize(self.kernel_initializer),
+                'bias_initializer': tf.keras.initializers.serialize(self.bias_initializer),
+                'mask_initializer': tf.keras.initializers.serialize(self.mask_initializer)
             }
         )
         return config
@@ -136,22 +140,24 @@ class MaskedConv2D(Layer):
         """
         if not self.use_bias:
             self.set_weights(
-                [self.w.numpy() * new_masks[0].astype(np.float32), new_masks[0].astype(np.float32)]
+                [self.w.numpy() * new_masks[0].astype(np.float32),
+                 new_masks[0].astype(np.float32)]
             )
         else:
             self.set_weights(
-                [self.w.numpy() * new_masks[0].astype(np.float32), self.b.numpy() * new_masks[1].astype(np.float32), new_masks[0].astype(np.float32), new_masks[1].astype(np.float32)]
+                [self.w.numpy() * new_masks[0].astype(np.float32), self.b.numpy() * new_masks[1].astype(
+                    np.float32), new_masks[0].astype(np.float32), new_masks[1].astype(np.float32)]
             )
 
     @classmethod
     def from_config(cls, config):
         return cls(
-            filters = config['filters'],
-            kernel_size = config['kernel_size'],
-            padding = config['padding'],
-            strides = config['strides'],
-            activation = config['activation'],
-            use_bias = config['use_bias'],
-            kernel_initializer = config['kernel_initializer'],
-            bias_initializer = config['bias_initializer']
+            filters=config['filters'],
+            kernel_size=config['kernel_size'],
+            padding=config['padding'],
+            strides=config['strides'],
+            activation=config['activation'],
+            use_bias=config['use_bias'],
+            kernel_initializer=config['kernel_initializer'],
+            bias_initializer=config['bias_initializer']
         )
