@@ -2,26 +2,26 @@ import numpy as np
 import tensorflow as tf
 from tensorflow.keras.layers import Layer
 
+
 class MultiConv2D(Layer):
     """
     Multitask 2-dimensional convolutional layer
 
     This layer implements multiple stacks of convolutional weights to account for different ways individual
     neurons activate for various tasks. It is expected that to train using the RSN2 algorithm that MultiMaskedConv2D
-    layers be used during training and then those layers be converted to this layer type.    
-    
+    layers be used during training and then those layers be converted to this layer type.
     """
-    
+
     def __init__(
         self,
         filters,
-        kernel_size = 3,
-        padding = 'same',
-        strides = 1,
-        use_bias = True,
-        activation = None,
-        kernel_initializer = 'random_normal',
-        bias_initializer = 'zeros',
+        kernel_size=3,
+        padding='same',
+        strides=1,
+        use_bias=True,
+        activation=None,
+        kernel_initializer='random_normal',
+        bias_initializer='zeros',
         **kwargs
     ):
         """
@@ -46,7 +46,8 @@ class MultiConv2D(Layer):
 
         """
         super(MultiConv2D, self).__init__(**kwargs)
-        self.filters = int(filters) if not isinstance(filters, int) else filters
+        self.filters = int(filters) if not isinstance(
+            filters, int) else filters
         self.kernel_size = kernel_size
         self.padding = padding
         self.strides = tuple(strides) if isinstance(strides, list) else strides
@@ -58,6 +59,7 @@ class MultiConv2D(Layer):
     @property
     def kernel_size(self):
         return self._kernel_size
+
     @kernel_size.setter
     def kernel_size(self, value):
         if isinstance(value, int):
@@ -70,23 +72,25 @@ class MultiConv2D(Layer):
             tuple(shape.as_list()) for shape in input_shape
         ]
         if len(set(input_shape)) != 1:
-            raise ValueError(f'All input shapes must be equal, got {input_shape}')
+            raise ValueError(
+                f'All input shapes must be equal, got {input_shape}')
 
         simplified_shape = input_shape[0]
 
         self.w = self.add_weight(
-            shape = (len(input_shape), self.kernel_size[0], self.kernel_size[1], simplified_shape[-1], self.filters),
-            initializer = self.kernel_initializer,
-            trainable = True,
-            name = 'weights'
+            shape=(len(input_shape),
+                   self.kernel_size[0], self.kernel_size[1], simplified_shape[-1], self.filters),
+            initializer=self.kernel_initializer,
+            trainable=True,
+            name='weights'
         )
 
         if self.use_bias:
             self.b = self.add_weight(
-                shape = (len(input_shape), self.filters),
-                initializer = self.bias_initializer,
-                trainable = True,
-                name = 'bias'
+                shape=(len(input_shape), self.filters),
+                initializer=self.bias_initializer,
+                trainable=True,
+                name='bias'
             )
 
     def call(self, inputs):
@@ -94,9 +98,9 @@ class MultiConv2D(Layer):
             tf.nn.convolution(
                 inputs[i],
                 self.w[i],
-                padding = self.padding.upper(),
-                strides = self.strides,
-                data_format = 'NHWC'
+                padding=self.padding.upper(),
+                strides=self.strides,
+                data_format='NHWC'
             ) for i in range(len(inputs))
         ]
         if self.use_bias:
@@ -109,14 +113,14 @@ class MultiConv2D(Layer):
         config = super().get_config().copy()
         config.update(
             {
-                'filters' : self.filters,
-                'kernel_size' : list(self.kernel_size),
-                'padding' : self.padding,
-                'strides' : self.strides,
-                'activation' : tf.keras.activations.serialize(self.activation),
-                'use_bias' : self.use_bias,
-                'kernel_initializer' : tf.keras.initializers.serialize(self.kernel_initializer),
-                'bias_initializer' : tf.keras.initializers.serialize(self.bias_initializer)
+                'filters': self.filters,
+                'kernel_size': list(self.kernel_size),
+                'padding': self.padding,
+                'strides': self.strides,
+                'activation': tf.keras.activations.serialize(self.activation),
+                'use_bias': self.use_bias,
+                'kernel_initializer': tf.keras.initializers.serialize(self.kernel_initializer),
+                'bias_initializer': tf.keras.initializers.serialize(self.bias_initializer)
             }
         )
         return config
@@ -124,12 +128,12 @@ class MultiConv2D(Layer):
     @classmethod
     def from_config(cls, config):
         return cls(
-            filters = config['filters'],
-            kernel_size = config['kernel_size'],
-            padding = config['padding'],
-            strides = config['strides'],
-            activation = config['activation'],
-            use_bias = config['use_bias'],
-            kernel_initializer = config['kernel_initializer'],
-            bias_initializer = config['bias_initializer']
+            filters=config['filters'],
+            kernel_size=config['kernel_size'],
+            padding=config['padding'],
+            strides=config['strides'],
+            activation=config['activation'],
+            use_bias=config['use_bias'],
+            kernel_initializer=config['kernel_initializer'],
+            bias_initializer=config['bias_initializer']
         )
