@@ -2,25 +2,25 @@ import numpy as np
 import tensorflow as tf
 from tensorflow.keras.layers import Layer
 
+
 class MultiMaskedConv2D(Layer):
     """
     Masked multitask 2-dimensional convolutional layer. This layer implements
     multiple stacks of the convolutional architecture and implements masking consistent
-    with the MANN API to support developing sparse multitask models.    
-
+    with the MANN API to support developing sparse multitask models.
     """
-    
+
     def __init__(
         self,
         filters,
-        kernel_size = 3,
-        padding = 'same',
-        strides = 1,
-        use_bias = True,
-        activation = None,
-        kernel_initializer = 'random_normal',
-        bias_initializer = 'zeros',
-        mask_initializer = 'ones',
+        kernel_size=3,
+        padding='same',
+        strides=1,
+        use_bias=True,
+        activation=None,
+        kernel_initializer='random_normal',
+        bias_initializer='zeros',
+        mask_initializer='ones',
         **kwargs
     ):
         """
@@ -47,7 +47,8 @@ class MultiMaskedConv2D(Layer):
 
         """
         super(MultiMaskedConv2D, self).__init__(**kwargs)
-        self.filters = int(filters) if not isinstance(filters, int) else filters
+        self.filters = int(filters) if not isinstance(
+            filters, int) else filters
         self.kernel_size = kernel_size
         self.padding = padding
         self.strides = tuple(strides) if isinstance(strides, list) else strides
@@ -60,6 +61,7 @@ class MultiMaskedConv2D(Layer):
     @property
     def kernel_size(self):
         return self._kernel_size
+
     @kernel_size.setter
     def kernel_size(self, value):
         if isinstance(value, int):
@@ -72,35 +74,37 @@ class MultiMaskedConv2D(Layer):
             tuple(shape.as_list()) for shape in input_shape
         ]
         if len(set(input_shape)) != 1:
-            raise ValueError(f'All input shapes must be equal, got {input_shape}')
+            raise ValueError(
+                f'All input shapes must be equal, got {input_shape}')
 
         simplified_shape = input_shape[0]
 
         self.w = self.add_weight(
-            shape = (len(input_shape), self.kernel_size[0], self.kernel_size[1], simplified_shape[-1], self.filters),
-            initializer = self.kernel_initializer,
-            trainable = True,
-            name = 'weights'
+            shape=(len(input_shape),
+                   self.kernel_size[0], self.kernel_size[1], simplified_shape[-1], self.filters),
+            initializer=self.kernel_initializer,
+            trainable=True,
+            name='weights'
         )
         self.w_mask = self.add_weight(
-            shape = self.w.shape,
-            initializer = self.mask_initializer,
-            trainable = False,
-            name = 'weights_mask'
+            shape=self.w.shape,
+            initializer=self.mask_initializer,
+            trainable=False,
+            name='weights_mask'
         )
 
         if self.use_bias:
             self.b = self.add_weight(
-                shape = (len(input_shape), self.filters),
-                initializer = self.bias_initializer,
-                trainable = True,
-                name = 'bias'
+                shape=(len(input_shape), self.filters),
+                initializer=self.bias_initializer,
+                trainable=True,
+                name='bias'
             )
             self.b_mask = self.add_weight(
-                shape = self.b.shape,
-                initializer = self.mask_initializer,
-                trainable = False,
-                name = 'bias_mask'
+                shape=self.b.shape,
+                initializer=self.mask_initializer,
+                trainable=False,
+                name='bias_mask'
             )
 
     def call(self, inputs):
@@ -108,9 +112,9 @@ class MultiMaskedConv2D(Layer):
             tf.nn.convolution(
                 inputs[i],
                 self.w[i] * self.w_mask[i],
-                padding = self.padding.upper(),
-                strides = self.strides,
-                data_format = 'NHWC'
+                padding=self.padding.upper(),
+                strides=self.strides,
+                data_format='NHWC'
             ) for i in range(len(inputs))
         ]
         if self.use_bias:
@@ -123,15 +127,15 @@ class MultiMaskedConv2D(Layer):
         config = super().get_config().copy()
         config.update(
             {
-                'filters' : self.filters,
-                'kernel_size' : list(self.kernel_size),
-                'padding' : self.padding,
-                'strides' : self.strides,
-                'activation' : tf.keras.activations.serialize(self.activation),
-                'use_bias' : self.use_bias,
-                'kernel_initializer' : tf.keras.initializers.serialize(self.kernel_initializer),
-                'bias_initializer' : tf.keras.initializers.serialize(self.bias_initializer),
-                'mask_initializer' : tf.keras.initializers.serialize(self.mask_initializer)
+                'filters': self.filters,
+                'kernel_size': list(self.kernel_size),
+                'padding': self.padding,
+                'strides': self.strides,
+                'activation': tf.keras.activations.serialize(self.activation),
+                'use_bias': self.use_bias,
+                'kernel_initializer': tf.keras.initializers.serialize(self.kernel_initializer),
+                'bias_initializer': tf.keras.initializers.serialize(self.bias_initializer),
+                'mask_initializer': tf.keras.initializers.serialize(self.mask_initializer)
             }
         )
         return config
@@ -139,22 +143,24 @@ class MultiMaskedConv2D(Layer):
     def set_masks(self, new_masks):
         if not self.use_bias:
             self.set_weights(
-                [self.w.numpy() * new_masks[0].astype(np.float), new_masks[0].astype(np.float)]
+                [self.w.numpy() * new_masks[0].astype(np.float),
+                 new_masks[0].astype(np.float)]
             )
         else:
             self.set_weights(
-                [self.w.numpy() * new_masks[0].astype(np.float), self.b.numpy() * new_masks[1].astype(np.float), new_masks[0].astype(np.float), new_masks[1].astype(np.float)]
+                [self.w.numpy() * new_masks[0].astype(np.float), self.b.numpy() * new_masks[1].astype(
+                    np.float), new_masks[0].astype(np.float), new_masks[1].astype(np.float)]
             )
 
     @classmethod
     def from_config(cls, config):
         return cls(
-            filters = config['filters'],
-            kernel_size = config['kernel_size'],
-            padding = config['padding'],
-            strides = config['strides'],
-            activation = config['activation'],
-            use_bias = config['use_bias'],
-            kernel_initializer = config['kernel_initializer'],
-            bias_initializer = config['bias_initializer']
+            filters=config['filters'],
+            kernel_size=config['kernel_size'],
+            padding=config['padding'],
+            strides=config['strides'],
+            activation=config['activation'],
+            use_bias=config['use_bias'],
+            kernel_initializer=config['kernel_initializer'],
+            bias_initializer=config['bias_initializer']
         )
